// Copyright © Microsoft Corporation
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//      http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

package org.opengroup.osdu.register.provider.azure.ddms;

import org.junit.jupiter.api.Test;
import org.junit.jupiter.api.extension.ExtendWith;
import org.mockito.junit.jupiter.MockitoExtension;
import java.sql.Timestamp;
import java.util.HashSet;
import java.util.Set;

import static org.junit.jupiter.api.Assertions.assertEquals;
import static org.junit.jupiter.api.Assertions.assertNotNull;

@ExtendWith(MockitoExtension.class)
public class DdmsDocTest {

    @Test
    public void shouldCreateActionDocWithAllArgsConstructor() {
        String id = "test-id";
        String name = "test-action";
        String description = "test-description";
        String contactEmail = "test@domain.com";
        Timestamp createdDateTimeEpoch = new Timestamp(System.currentTimeMillis());
        String dataPartitionId = "opendes";
        Set<RegisteredInterfaceDoc>registeredInterfaceDoc = new HashSet<>();

        DdmsDoc doc = new DdmsDoc(id, name, description, contactEmail, createdDateTimeEpoch, dataPartitionId, registeredInterfaceDoc);

        assertNotNull(doc);
        assertEquals(id, doc.getId());
        assertEquals(name, doc.getName());
        assertEquals(description, doc.getDescription());
        assertEquals(contactEmail, doc.getContactEmail());
        assertEquals(createdDateTimeEpoch, doc.getCreatedDateTimeEpoch());
        assertEquals(dataPartitionId, doc.getDataPartitionId());
        assertEquals(registeredInterfaceDoc, doc.getInterfaces());
    }

    @Test
    public void shouldCreateDdmsDocWithNoArgsConstructor() {
        DdmsDoc doc = new DdmsDoc();
        assertNotNull(doc);
    }
}
