/*
  Copyright 2021 Google LLC
  Copyright 2021 EPAM Systems, Inc

  Licensed under the Apache License, Version 2.0 (the "License");
  you may not use this file except in compliance with the License.
  You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

  Unless required by applicable law or agreed to in writing, software
  distributed under the License is distributed on an "AS IS" BASIS,
  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
  See the License for the specific language governing permissions and
  limitations under the License.
 */

package org.opengroup.osdu.register.provider.reference.mapper;

import java.sql.Timestamp;
import org.opengroup.osdu.register.action.model.Action;
import org.opengroup.osdu.register.provider.reference.model.document.ActionDocument;
import org.springframework.stereotype.Component;

@Component
public class ActionMapper {

  public Action toAction(ActionDocument document) {
    if (document == null) {
      return null;
    }

    Action action = new Action();
    action.setId(document.getId());
    action.setName(document.getName());
    action.setDescription(document.getDescription());
    action.setImg(document.getImg());
    action.setUrl(document.getUrl());
    action.setContactEmail(document.getContactEmail());
    action.setCreatedOnEpoch(Timestamp.from(document.getCreatedOn().toInstant()));
    action.setFilter(document.getFilter());

    return action;
  }

  public ActionDocument toDocument(Action action, String checkSum) {
    return ActionDocument.builder()
        .id(action.getId())
        .name(action.getName())
        .description(action.getDescription())
        .img(action.getImg())
        .url(action.getUrl())
        .contactEmail(action.getContactEmail())
        .createdOn(action.getCreatedOnEpoch())
        .filter(action.getFilter())
        .checkSum(checkSum)
        .build();
  }
}
