/*
  Copyright 2021 Google LLC
  Copyright 2021 EPAM Systems, Inc

  Licensed under the Apache License, Version 2.0 (the "License");
  you may not use this file except in compliance with the License.
  You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

  Unless required by applicable law or agreed to in writing, software
  distributed under the License is distributed on an "AS IS" BASIS,
  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
  See the License for the specific language governing permissions and
  limitations under the License.
 */

package org.opengroup.osdu.register.provider.reference.mapper;

import com.google.gson.Gson;
import java.sql.Timestamp;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import org.opengroup.osdu.register.ddms.model.Ddms;
import org.opengroup.osdu.register.ddms.model.RegisteredInterface;
import org.opengroup.osdu.register.provider.reference.model.MongoRegisteredInterfaces;
import org.opengroup.osdu.register.provider.reference.model.document.DdmsDocument;
import org.springframework.stereotype.Component;

@Component
public class DdmsMapper {

  private static final Gson gson = new Gson();

  public Ddms toDdms(DdmsDocument document) {
    if (document == null) {
      return null;
    }

    Ddms ddms = new Ddms();
    ddms.setId(document.getId());
    ddms.setName(document.getName());
    ddms.setDescription(document.getDescription());
    ddms.setContactEmail(document.getContactEmail());
    ddms.setCreatedDateTimeEpoch(Timestamp.from(document.getCreatedOn().toInstant()));

    List<MongoRegisteredInterfaces> mongoRegisteredInterfaces = document.getInterfaces();
    mongoRegisteredInterfaces.forEach(i -> {
      RegisteredInterface ri = new RegisteredInterface();
      ri.setEntityType(i.getEntityType());
      Map<String, Object> schema = gson.fromJson(i.getSchema(), Map.class);
      ri.setSchema(schema);
      ddms.getInterfaces().add(ri);
    });

    return ddms;
  }

  public DdmsDocument toDocument(Ddms ddms) {
    List<MongoRegisteredInterfaces> dmsInterfaces = new ArrayList<>();
    for (RegisteredInterface ri : ddms.getInterfaces()) {
      String schema = gson.toJson(ri.getSchema());
      MongoRegisteredInterfaces mongoRegisteredInterface = new MongoRegisteredInterfaces(
          ri.getEntityType(), schema);
      dmsInterfaces.add(mongoRegisteredInterface);
    }

    return DdmsDocument.builder()
        .id(ddms.getId())
        .name(ddms.getName())
        .description(ddms.getDescription())
        .contactEmail(ddms.getContactEmail())
        .createdOn(ddms.getCreatedDateTimeEpoch())
        .interfaces(dmsInterfaces)
        .build();
  }
}
