/*
  Copyright 2021 Google LLC
  Copyright 2021 EPAM Systems, Inc

  Licensed under the Apache License, Version 2.0 (the "License");
  you may not use this file except in compliance with the License.
  You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

  Unless required by applicable law or agreed to in writing, software
  distributed under the License is distributed on an "AS IS" BASIS,
  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
  See the License for the specific language governing permissions and
  limitations under the License.
 */

package org.opengroup.osdu.register.provider.reference.verifier;

import com.google.api.client.googleapis.auth.oauth2.GoogleIdToken;
import com.google.api.client.googleapis.auth.oauth2.GoogleIdTokenVerifier;
import com.google.api.client.http.javanet.NetHttpTransport;
import com.google.api.client.json.jackson2.JacksonFactory;
import com.google.common.base.Strings;
import java.util.Collections;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.opengroup.osdu.register.provider.interfaces.verifier.GsaTokenVerifier;
import org.opengroup.osdu.register.utils.AppServiceConfig;
import org.springframework.stereotype.Component;

@Slf4j
@Component
@RequiredArgsConstructor
public class GsaTokenVerifierImpl implements GsaTokenVerifier {

  private static final String INTERNAL_SERVER_ERROR_MESSAGE = "An error occurred while verifying token.";

  private final AppServiceConfig serviceConfig;

  public boolean verify(String token) {
    if (Strings.isNullOrEmpty(token)) {
      return true;
    }
    try {
      GoogleIdTokenVerifier verifier = new GoogleIdTokenVerifier.Builder(new NetHttpTransport(),
          JacksonFactory.getDefaultInstance())
          .setAudience(
              Collections.singletonList(this.serviceConfig.getIntegrationTestJwtAudiences()))
          .build();
      GoogleIdToken idToken = verifier.verify(token);
      return idToken != null;
    } catch (Exception ex) {
      log.error(INTERNAL_SERVER_ERROR_MESSAGE);
      return false;
    }
  }
}
